@@ -160,7 +160,7 @@ class Auth:
         self.save_function_spec (f)
         @wraps(f)
         def wrapper (was, *args, **kwargs):
-            if not was.csrf_verify ():
+            if not was.verify_csrf ():
                 raise was.Error ("400 Bad Request", 'CSRF token error')
             return f (was, *args, **kwargs)
         return wrapper
