@@ -180,7 +180,7 @@ class WAS (wsgiappservice.WAS):
     def csrf_token_input (self):
         return '<input type="hidden" name="{}" value="{}">'.format (self.CSRF_NAME, self.csrf_token)
 
-    def csrf_verify (self, keep = False):
+    def verify_csrf (self, keep = False):
         token = self.request.get_header ('x-csrf-token', self.request.args.get (self.CSRF_NAME))
         if not token:
             return False
@@ -190,6 +190,7 @@ class WAS (wsgiappservice.WAS):
                 del self.session [self.CSRF_NAME]
             return True
         return False
+    csrf_verify = verify_csrf
 
     # response shortcuts -----------------------------------------------
     REDIRECT_TEMPLATE =  (
